rnalysis.filtering.CountFilter
==============================

.. currentmodule:: rnalysis.filtering

.. autoclass:: CountFilter


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::
    :toctree:

      ~CountFilter.__init__
      ~CountFilter.biotypes
      ~CountFilter.clustergram
      ~CountFilter.describe
      ~CountFilter.difference
      ~CountFilter.filter_biotype
      ~CountFilter.filter_by_ref_table_attr
      ~CountFilter.filter_by_row_sum
      ~CountFilter.filter_low_reads
      ~CountFilter.filter_percentile
      ~CountFilter.filter_top_n
      ~CountFilter.fold_change
      ~CountFilter.from_folder
      ~CountFilter.head
      ~CountFilter.intersection
      ~CountFilter.norm_reads_to_rpm
      ~CountFilter.norm_reads_with_size_factor
      ~CountFilter.number_filters
      ~CountFilter.pairplot
      ~CountFilter.pca
      ~CountFilter.plot_expression
      ~CountFilter.print_features
      ~CountFilter.save_csv
      ~CountFilter.scatter_sample_vs_sample
      ~CountFilter.split_by_percentile
      ~CountFilter.split_by_reads
      ~CountFilter.split_by_ref_table_attr
      ~CountFilter.symmetric_difference
      ~CountFilter.tail
      ~CountFilter.text_filters
      ~CountFilter.union
      ~CountFilter.violin_plot

